@@ -1,12 +1,14 @@
 import json
 import logging
 import os
+from pathlib import Path
 from typing import Callable, Dict, List, Optional
 
 import pandas
 from fastapi.encoders import jsonable_encoder
 
 from .accuracy import calibration, largest_errors, metrics, roc_curve
+from .countplot import countplot
 from .dependence import partialdep
 from .expectations import condexp
 from .importance import varimp
@@ -117,7 +119,10 @@ def create_accuracy(
 
 
 def create_dependence(
-    func: Callable, x: pandas.DataFrame, endpoint_name: str, profile_columns: List[str],
+    func: Callable,
+    x: pandas.DataFrame,
+    endpoint_name: str,
+    profile_columns: List[str],
 ) -> None:
     """Create partial dependence graphs for all variables"""
 
@@ -162,6 +167,21 @@ def create_expectations(
             logging.warning(f"Could not generate valid chart for {var}: {repr(e)}")
 
 
+def create_countplot(
+    x: pandas.DataFrame, endpoint_name: str, profile_columns: List[str]
+) -> None:
+    """Create count plot graphs for all variables in profile_columns, creates folder structure and saves the plots to named files."""
+
+    folder = mkdir(endpoint_name=endpoint_name, spec_path="anatomy/countplot")
+
+    for var in profile_columns:
+        logging.info(f"Explanations - Creating count plot for {var}")
+        file_name = var + ".json"
+        file_path = Path(folder, file_name)
+        chart = countplot(x[var])
+        chart.save(str(file_path), format="json")
+
+
 def create_slice_loss(
     func: Callable,
     x: pandas.DataFrame,
@@ -184,11 +204,8 @@ def create_slice_loss(
         logging.info(f"Explanations - Creating slice loss for {var}")
         fname = var + ".json"
         fpath = os.path.join(folder, fname)
-        try:
-            chart = slice_loss(func, x, y, var, loss)
-            chart.save(fpath, format="json")
-        except Exception as e:
-            logging.warning(e)
+        chart = slice_loss(func, x, y, var, loss)
+        chart.save(fpath, format="json")
 
 
 def create_importance(
@@ -226,6 +243,8 @@ def create_summary(
     path: Optional[str] = None,
     explain_path: Optional[str] = None,
     version: Optional[str] = None,
+    tags: Optional[List[str]] = None,
+    position: Optional[int] = None,
 ) -> None:
 
     logging.info(f"Summary - creating endpoint summary for endpoint: {endpoint_name}")
@@ -234,6 +253,8 @@ def create_summary(
         "kind": kind,
         "inputs": input_names,
         "output": output_names,
+        "tags": tags if tags else [],
+        "position": position if position else 0,
     }
     if version is not None:
         as_json["version"] = version
